```{include} _templates/nav.html
```

# reuters-style

A Python library that format dates, numbers and text to conform with the Reuters Style Guide, the standards that guide the world's largest independent newsroom

## Installation

Install the package from the Python Package Index (PyPI) with pipenv:

```bash
pipenv install reuters-style
```

## Usage

The library currently features the following methods and objects:

* [date](#reuters_style.date)
* [dayofweek](#reuters_style.dayofweek)
* [time](#reuters_style.time)
* [validate_slug](#reuters_style.validate_slug)
* [validate_packaging_slug](#reuters_style.validate_packaging_slug)
* [validate_wild_slug](#reuters_style.validate_wild_slug)
* [RIC](#reuters_style.RIC)
* [Slug](#reuters_style.Slug)

```{eval-rst}
.. automodule:: reuters_style
```

## Links

- Documentation: [palewi.re/docs/reuters-style/](https://palewi.re/docs/reuters-style/)
- Code: [github.com/palewire/reuters-style](https://github.com/palewire/reuters-style)
- Issues: [github.com/palewire/reuters-style/issues](https://github.com/palewire/reuters-style/issues)
- Packaging: [pypi.org/project/reuters-style](https://pypi.org/project/reuters-style)
